Skip to main content Module commands Copy item path Source absorb add agent_profile Generic agent profile system — extends the swarm subsystem from SWE-only
agents to arbitrary domain agents (CAD designers, EDA engineers, writers,
DBAs, reviewers, CI bots, security auditors, etc.). ai amend batch bisect blame branch checkout cherry_pick clean clone commit config content_type Content type system — extends Lit from SWE-only VCS to a universal
versioning system for CAD, EDA, manuscripts, databases, scientific data,
media assets, and arbitrary domain content. converge Converge — merge intent commits into the mainline datacenter Datacenter deployment optimizations — cluster node management, object store
sharding, replication factor control, health monitoring, Prometheus-style
metrics, and connection pooling configuration. delegate Agent Task Delegation Protocol diff export_git fetch gc import_git init intent Intent-based workflow for agentic development issue Issues stored as git refs inside the repository lfs log mcp_serve merge migrate_encryption Encrypt a repository that was created before encryption was switched on. pr Pull Requests stored as git refs inside the repository pull push rebase reflog remote reset resolve revert reword rotate_key sandbox search serve show snapshot squash stack stash status swarm tag transaction uncommit undo verify watch workspace