execute

Function execute 

pub fn execute(dry_run: bool) -> Result<CleanResponse, LitError>
Remove empty branches from the workspace. A branch is considered “empty” if it points to the same commit as its base/parent branch or is identical to the default branch.