pub fn execute() -> Result<GcResponse, LitError>Expand description
Execute the gc (garbage collection) command.
Packs all loose objects into a single pack file and removes the loose files.
pub fn execute() -> Result<GcResponse, LitError>Execute the gc (garbage collection) command.
Packs all loose objects into a single pack file and removes the loose files.