pub fn execute_push(name: String) -> Result<StackResponse, LitError>Expand description
Push a new branch onto the current branch (creating a stacked branch)
pub fn execute_push(name: String) -> Result<StackResponse, LitError>Push a new branch onto the current branch (creating a stacked branch)