pub fn execute(discard: bool) -> Result<CommitResponse, LitError>Expand description
Uncommit the last commit, keeping changes in the working tree. With –discard, also drops the committed content.
pub fn execute(discard: bool) -> Result<CommitResponse, LitError>Uncommit the last commit, keeping changes in the working tree. With –discard, also drops the committed content.