pub fn word_diff_line(old_line: &str, new_line: &str) -> Vec<WordDiffSegment>Expand description
Compute word-level diff between two lines that were changed
Returns a sequence of segments marking equal, added, and removed words.
pub fn word_diff_line(old_line: &str, new_line: &str) -> Vec<WordDiffSegment>Compute word-level diff between two lines that were changed
Returns a sequence of segments marking equal, added, and removed words.