HTTPS transport for remote Lit repositories
Communicates with a remote lit serve instance over HTTP/HTTPS.
Uses the transport API endpoints for object and ref transfer.
Functions
- download_
objects_ http - Download objects from a remote server into a local store
- is_
https_ url - Check whether a URL uses the HTTPS transport
- list_
refs_ http - List refs from a remote server
- negotiate_
http - Negotiate which objects are needed (server-side graph walk)
- read_
head_ http - Read HEAD from a remote server
- read_
ref_ http - Read a branch ref from a remote server
- update_
ref_ http - Update a branch ref on a remote server
- upload_
objects_ http - Upload objects from a local store to a remote server