pub fn download_objects_http(
base_url: &str,
local_store: &ObjectStore,
hashes: &[ObjectHash],
token: Option<&str>,
) -> Result<usize, String>Expand description
Download objects from a remote server into a local store
pub fn download_objects_http(
base_url: &str,
local_store: &ObjectStore,
hashes: &[ObjectHash],
token: Option<&str>,
) -> Result<usize, String>Download objects from a remote server into a local store