pub fn upload_objects_http(
base_url: &str,
local_store: &ObjectStore,
hashes: &[ObjectHash],
token: Option<&str>,
) -> Result<usize, String>Expand description
Upload objects from a local store to a remote server
pub fn upload_objects_http(
base_url: &str,
local_store: &ObjectStore,
hashes: &[ObjectHash],
token: Option<&str>,
) -> Result<usize, String>Upload objects from a local store to a remote server