pub fn upload_objects_lit(
conn: &mut LitConnection,
local_store: &ObjectStore,
hashes: &[ObjectHash],
) -> Result<usize, String>Expand description
Upload objects from a local store to a remote server via lit:// connection
pub fn upload_objects_lit(
conn: &mut LitConnection,
local_store: &ObjectStore,
hashes: &[ObjectHash],
) -> Result<usize, String>Upload objects from a local store to a remote server via lit:// connection