Module ssh

Module ssh 

SSH transport for remote Lit repositories

Communicates with a remote lit serve --stdio instance over SSH. The SSH client spawns the system ssh command and communicates via newline-delimited JSON over stdin/stdout pipes.

Structs

SshPipe
An SSH pipe connection to a remote lit serve --stdio instance
SshUrl
Parsed SSH URL components

Functions

download_objects_ssh
Download objects from a remote server via SSH pipe
is_ssh_url
Check whether a URL uses the SSH transport
list_refs_ssh
List refs from a remote server via SSH pipe
negotiate_ssh
Negotiate which objects are needed via SSH pipe
parse_ssh_url
Parse an SSH URL into its components.
read_head_ssh
Read HEAD from a remote server via SSH pipe
read_ref_ssh
Read a branch ref from a remote server via SSH pipe
update_ref_ssh
Update a branch ref on a remote server via SSH pipe
upload_objects_ssh
Upload objects from a local store to a remote server via SSH pipe