pub fn upload_objects_ssh(
pipe: &mut SshPipe,
local_store: &ObjectStore,
hashes: &[ObjectHash],
) -> Result<usize, String>Expand description
Upload objects from a local store to a remote server via SSH pipe
pub fn upload_objects_ssh(
pipe: &mut SshPipe,
local_store: &ObjectStore,
hashes: &[ObjectHash],
) -> Result<usize, String>Upload objects from a local store to a remote server via SSH pipe