execute

Function execute 

pub fn execute(
    base: Option<String>,
    dry_run: bool,
) -> Result<AbsorbResponse, LitError>
Absorb working directory changes into the correct ancestor commits. Analyzes each modified file’s hunks and determines which commit last touched those lines, then amends that commit with the changes.