Module https

Module https 

HTTPS transport for remote Lit repositories

Communicates with a remote lit serve instance over HTTP/HTTPS. Uses the transport API endpoints for object and ref transfer.

Functions

download_objects_http
Download objects from a remote server into a local store
is_https_url
Check whether a URL uses the HTTPS transport
list_refs_http
List refs from a remote server
negotiate_http
Negotiate which objects are needed (server-side graph walk)
read_head_http
Read HEAD from a remote server
read_ref_http
Read a branch ref from a remote server
update_ref_http
Update a branch ref on a remote server
upload_objects_http
Upload objects from a local store to a remote server