SSH transport for remote Lit repositories
Communicates with a remote lit serve --stdio instance over SSH.
The SSH client spawns the system ssh command and communicates
via newline-delimited JSON over stdin/stdout pipes.
Structs
Functions
- download_
objects_ ssh - Download objects from a remote server via SSH pipe
- is_
ssh_ url - Check whether a URL uses the SSH transport
- list_
refs_ ssh - List refs from a remote server via SSH pipe
- negotiate_
ssh - Negotiate which objects are needed via SSH pipe
- parse_
ssh_ url - Parse an SSH URL into its components.
- read_
head_ ssh - Read HEAD from a remote server via SSH pipe
- read_
ref_ ssh - Read a branch ref from a remote server via SSH pipe
- update_
ref_ ssh - Update a branch ref on a remote server via SSH pipe
- upload_
objects_ ssh - Upload objects from a local store to a remote server via SSH pipe